@@ -24,11 +24,11 @@ use namespace::clean;
 
 =head1 NAME
 
-Net::Etcd
+Net::Etcd - etcd v3 REST API.
 
 =cut
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 =head1 SYNOPSIS
 
@@ -308,6 +308,18 @@ Returns a L<Net::Etcd::KV::Txn> object.
 
 =cut
 
+=head2 op
+
+Returns a L<Net::Etcd::KV::Op> object.
+
+=cut
+
+=head2 compare
+
+Returns a L<Net::Etcd::KV::Compare> object.
+
+=cut
+
 =head2 configuration
 
 Initialize configuration checks to see it etcd is installed locally.
