@@ -22,7 +22,7 @@ Net::Etcd::Role::Actions
 
 =cut
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 has etcd => (
     is  => 'ro',
@@ -41,7 +41,7 @@ sub _build_json_args {
     my ($self) = @_;
     my $args;
     for my $key ( keys %{$self} ) {
-        unless ( $key =~ /(?:etcd|cb|cv|json_args|endpoint)$/ ) {
+        unless ( $key =~ /(?:etcd|cb|cv|hold|json_args|endpoint)$/ ) {
             $args->{$key} = $self->{$key};
         }
     }
@@ -86,6 +86,15 @@ sub init {
 
 has headers => ( is => 'ro' );
 
+=head2 hold
+
+When set will not fire request.
+
+=cut
+
+has hold => ( is => 'ro' );
+
+
 =head2 response
 
 =cut
